=======
History
=======

0.2.0 (2022-02-15)
------------------

* Dropped support for Python 3.6
* Added support for Python 3.10
* ``find_school_names`` now returns ``None`` if the source school name could not be utf-8 decoded
* Reduced the number of files in deployment by vendoring the sources

0.1.3 (2021-03-02)
------------------

* Updates domain sources
* Adds tests on Python 3.9

0.1.2 (2020-09-26)
------------------

* Fixes missing files and non-utf8 institution names

0.1.0 (2020-09-25)
------------------

* First release on PyPI.
